@@ -64,6 +64,7 @@ G_BEGIN_DECLS
 #define FOURCC_VP80     GST_MAKE_FOURCC('V','P','8','0')
 #define FOURCC_WRLE     GST_MAKE_FOURCC('W','R','L','E')
 #define FOURCC_XMP_     GST_MAKE_FOURCC('X','M','P','_')
+#define FOURCC_XVID     GST_MAKE_FOURCC('X','V','I','D')
 #define FOURCC__ART     GST_MAKE_FOURCC(0xa9,'A','R','T')
 #define FOURCC_____     GST_MAKE_FOURCC('-','-','-','-')
 #define FOURCC___in     GST_MAKE_FOURCC(' ',' ','i','n')
@@ -86,6 +87,8 @@ G_BEGIN_DECLS
 #define FOURCC_ac_3     GST_MAKE_FOURCC('a','c','-','3')
 #define FOURCC_agsm     GST_MAKE_FOURCC('a','g','s','m')
 #define FOURCC_alac     GST_MAKE_FOURCC('a','l','a','c')
+#define FOURCC_fLaC     GST_MAKE_FOURCC('f','L','a','C')
+#define FOURCC_dfLa     GST_MAKE_FOURCC('d','f','L','a')
 #define FOURCC_alaw     GST_MAKE_FOURCC('a','l','a','w')
 #define FOURCC_alis     GST_MAKE_FOURCC('a','l','i','s')
 #define FOURCC_appl     GST_MAKE_FOURCC('a','p','p','l')
@@ -169,9 +172,14 @@ G_BEGIN_DECLS
 #define FOURCC_mp4s     GST_MAKE_FOURCC('m','p','4','s')
 #define FOURCC_mp4v     GST_MAKE_FOURCC('m','p','4','v')
 #define FOURCC_name     GST_MAKE_FOURCC('n','a','m','e')
+#define FOURCC_nclc     GST_MAKE_FOURCC('n','c','l','c')
+#define FOURCC_nclx     GST_MAKE_FOURCC('n','c','l','x')
 #define FOURCC_opus     GST_MAKE_FOURCC('O','p','u','s')
 #define FOURCC_dops     GST_MAKE_FOURCC('d','O','p','s')
 #define FOURCC_pasp     GST_MAKE_FOURCC('p','a','s','p')
+#define FOURCC_colr     GST_MAKE_FOURCC('c','o','l','r')
+#define FOURCC_clap     GST_MAKE_FOURCC('c','l','a','p')
+#define FOURCC_fiel     GST_MAKE_FOURCC('f','i','e','l')
 #define FOURCC_pcst     GST_MAKE_FOURCC('p','c','s','t')
 #define FOURCC_pgap     GST_MAKE_FOURCC('p','g','a','p')
 #define FOURCC_pnot     GST_MAKE_FOURCC('p','n','o','t')
@@ -212,6 +220,7 @@ G_BEGIN_DECLS
 #define FOURCC_stss     GST_MAKE_FOURCC('s','t','s','s')
 #define FOURCC_stsz     GST_MAKE_FOURCC('s','t','s','z')
 #define FOURCC_stts     GST_MAKE_FOURCC('s','t','t','s')
+#define FOURCC_styp     GST_MAKE_FOURCC('s','t','y','p')
 #define FOURCC_subp     GST_MAKE_FOURCC('s','u','b','p')
 #define FOURCC_subt     GST_MAKE_FOURCC('s','u','b','t')
 #define FOURCC_text     GST_MAKE_FOURCC('t','e','x','t')
@@ -236,10 +245,12 @@ G_BEGIN_DECLS
 #define FOURCC_vc_1     GST_MAKE_FOURCC('v','c','-','1')
 #define FOURCC_vide     GST_MAKE_FOURCC('v','i','d','e')
 #define FOURCC_vmhd     GST_MAKE_FOURCC('v','m','h','d')
+#define FOURCC_xvid     GST_MAKE_FOURCC('x','v','i','d')
 #define FOURCC_wave     GST_MAKE_FOURCC('w','a','v','e')
 #define FOURCC_wide     GST_MAKE_FOURCC('w','i','d','e')
 #define FOURCC_zlib     GST_MAKE_FOURCC('z','l','i','b')
 
+#define FOURCC_ap4x     GST_MAKE_FOURCC('a','p','4','x')
 #define FOURCC_ap4h     GST_MAKE_FOURCC('a','p','4','h')
 #define FOURCC_apch     GST_MAKE_FOURCC('a','p','c','h')
 #define FOURCC_apcn     GST_MAKE_FOURCC('a','p','c','n')
@@ -284,8 +295,6 @@ G_BEGIN_DECLS
 /* ISO Motion JPEG 2000 fourcc */
 #define FOURCC_cdef     GST_MAKE_FOURCC('c','d','e','f')
 #define FOURCC_cmap     GST_MAKE_FOURCC('c','m','a','p')
-#define FOURCC_colr     GST_MAKE_FOURCC('c','o','l','r')
-#define FOURCC_fiel     GST_MAKE_FOURCC('f','i','e','l')
 #define FOURCC_ihdr     GST_MAKE_FOURCC('i','h','d','r')
 #define FOURCC_jp2h     GST_MAKE_FOURCC('j','p','2','h')
 #define FOURCC_jp2x     GST_MAKE_FOURCC('j','p','2','x')
