@@ -340,6 +340,9 @@ qtdemux_dump_stsd (GstQTDemux * qtdemux, GstByteReader * data, int depth)
         if (!qtdemux_dump_stsd_avc1 (qtdemux, &sub, size, depth + 1))
           return FALSE;
         break;
+      case FOURCC_fLaC:
+        /* will be dumped by node_dump_foreach */
+        break;
       case FOURCC_mp4s:
         if (!gst_byte_reader_get_uint32_be (&sub, &ver_flags) ||
             !gst_byte_reader_get_uint32_be (&sub, &num_entries))
@@ -890,6 +893,70 @@ qtdemux_dump_svmi (GstQTDemux * qtdemux, GstByteReader * data, int depth)
   return TRUE;
 }
 
+gboolean
+qtdemux_dump_dfLa (GstQTDemux * qtdemux, GstByteReader * data, int depth)
+{
+  const gchar *block_types[] = {
+    "STREAMINFO", "PADDING", "APPLICATION", "SEEKTABLE", "VORBIS_COMMENT",
+    "CUESHEET", "PICTURE", "UNKNOWN", "INVALID"
+  };
+
+  guint32 ver_flags, block_header, block_size;
+  gint8 block_type;
+  gboolean isLast = FALSE;
+
+  if (!gst_byte_reader_get_uint32_be (data, &ver_flags))
+    return FALSE;
+
+  GST_LOG ("%*s  version/flags: %08x", depth, "", ver_flags);
+
+  do {
+    if (!gst_byte_reader_get_uint32_be (data, &block_header))
+      break;
+
+    isLast = (block_header >> 31) & 1;
+    block_type = (block_header >> 24) & 0x7F;
+    block_size = block_header & 0xFFFFFF;
+
+    if (block_type == 127)
+      block_type = 8;
+    else if (block_type > 6)
+      block_type = 7;
+
+    GST_LOG ("%*s  block_type:      %s", depth, "", block_types[block_type]);
+    GST_LOG ("%*s  last-block-flag: %s", depth, "", isLast ? "true" : "false");
+    GST_LOG ("%*s  length:          %d", depth, "", block_size);
+
+    if (!gst_byte_reader_skip (data, block_size))
+      break;
+  } while (!isLast);
+
+  return TRUE;
+}
+
+gboolean
+qtdemux_dump_fLaC (GstQTDemux * qtdemux, GstByteReader * data, int depth)
+{
+  guint16 data_ref_id, n_channels, sample_size;
+  guint32 sample_rate;
+
+  if (!gst_byte_reader_skip (data, 6) ||
+      !gst_byte_reader_get_uint16_be (data, &data_ref_id) ||
+      !gst_byte_reader_skip (data, 8) ||
+      !gst_byte_reader_get_uint16_be (data, &n_channels) ||
+      !gst_byte_reader_get_uint16_be (data, &sample_size) ||
+      !gst_byte_reader_skip (data, 4) ||
+      !gst_byte_reader_get_uint32_be (data, &sample_rate))
+    return FALSE;
+
+  GST_LOG ("%*s  data reference: %d", depth, "", data_ref_id);
+  GST_LOG ("%*s  channel count:  %d", depth, "", n_channels);
+  GST_LOG ("%*s  sample size:    %d", depth, "", sample_size);
+  GST_LOG ("%*s  sample rate:    %d", depth, "", (sample_rate >> 16));
+
+  return TRUE;
+}
+
 gboolean
 qtdemux_dump_unknown (GstQTDemux * qtdemux, GstByteReader * data, int depth)
 {
